@@ -1,10 +1,13 @@
-
+# Copyright (C) 2012-2014 The python-bitcoinlib developers
 #
-# serialize.py
+# This file is part of python-bitcoinlib.
 #
-# Distributed under the MIT/X11 software license, see the accompanying
-# file COPYING or http://www.opensource.org/licenses/mit-license.php.
+# It is subject to the license terms in the LICENSE file found in the top-level
+# directory of this distribution.
 #
+# No part of python-bitcoinlib, including this file, may be copied, modified,
+# propagated, or distributed except according to the terms contained in the
+# LICENSE file.
 
 """Serialization routines
 
@@ -46,12 +49,23 @@ class SerializationError(Exception):
     """Base class for serialization errors"""
 
 
-class SerializationTruncationError(Exception):
+class SerializationTruncationError(SerializationError):
     """Serialized data was truncated
 
     Thrown by deserialize() and stream_deserialize()
     """
 
+class DeserializationExtraDataError(SerializationError):
+    """Deserialized data had extra data at the end
+
+    Thrown by deserialize() when not all data is consumed during
+    deserialization. The deserialized object and extra padding not consumed are
+    saved.
+    """
+    def __init__(self, msg, obj, padding):
+        super(DeserializationExtraDataError, self).__init__(msg)
+        self.obj = obj
+        self.padding = padding
 
 def ser_read(f, n):
     """Read from a stream safely
@@ -70,6 +84,9 @@ def ser_read(f, n):
 
 class Serializable(object):
     """Base class for serializable objects"""
+
+    __slots__ = []
+
     def stream_serialize(self, f):
         """Serialize to a stream"""
         raise NotImplementedError
@@ -86,9 +103,22 @@ class Serializable(object):
         return f.getvalue()
 
     @classmethod
-    def deserialize(cls, buf):
-        """Deserialize bytes, returning an instance"""
-        return cls.stream_deserialize(BytesIO(buf))
+    def deserialize(cls, buf, allow_padding=False):
+        """Deserialize bytes, returning an instance
+
+        allow_padding - Allow buf to include extra padding. (default False)
+
+        If allow_padding is False and not all bytes are consumed during
+        deserialization DeserializationExtraDataError will be raised.
+        """
+        fd = BytesIO(buf)
+        r = cls.stream_deserialize(fd)
+        if not allow_padding:
+            padding = fd.read()
+            if len(padding) != 0:
+                raise DeserializationExtraDataError('Not all bytes consumed during deserialization',
+                                                    r, padding)
+        return r
 
     def GetHash(self):
         """Return the hash of the serialized object"""
